@@ -195,9 +195,13 @@ def parse_construction_info(construction_info_path: Path) -> Order:
             tooth_type = get_text(tooth_node, 'ReconstructionType')
             tooth_is_anatomical = None
             tooth_implant_type = get_text(tooth_node, 'ImplantType')
+            implant_system = None
+
+            if part_type == 'Abutment':
+                implant_system = get_text(tooth_node, 'ImplantLibraryEntryDescriptor')
 
             tooth = Tooth(fdi=tooth_number, color=tooth_color, type=tooth_type,
-                    is_anatomical=tooth_is_anatomical, implant_type=tooth_implant_type)
+                    is_anatomical=tooth_is_anatomical, implant_type=tooth_implant_type, implant_system=implant_system)
             teeth.append(tooth)
 
         color = consolidate_colors(teeth)
@@ -248,9 +252,10 @@ def parse_model_info(model_info_path: Path) -> Order:
             tooth_type = get_text(tooth_node, 'ReconstructionType')
             tooth_is_anatomical = None
             tooth_implant_type = None
+            implant_system = None
 
             tooth = Tooth(fdi=tooth_number, color=tooth_color, type=tooth_type,
-                    is_anatomical=tooth_is_anatomical, implant_type=tooth_implant_type)
+                    is_anatomical=tooth_is_anatomical, implant_type=tooth_implant_type, implant_system=implant_system)
             teeth.append(tooth)
 
         color = consolidate_colors(teeth)
