@@ -25,8 +25,9 @@ class TestExocad(unittest.TestCase):
         project_types = filter(lambda x: x.is_dir(), project_types)
         for project_type in project_types:
             for project in project_type.iterdir():
-                if(project.name == 'MissingConstructionInfo'):
+                if project.name == 'MissingConstructionInfo' or project.is_file():
                     continue
+                
                 self.assertTrue(exocad.is_supported(project), f"{project} is not supported")
                 
     def test_parse_dental_project(self):
@@ -34,7 +35,7 @@ class TestExocad(unittest.TestCase):
         project_types = filter(lambda x: x.is_dir(), project_types)
         for project_type in project_types:
             for project in project_type.iterdir():
-                if(project.name == 'MissingConstructionInfo'):
+                if project.name == 'MissingConstructionInfo' or project.is_file():
                     continue
                 dental_project_path = next(project.glob('*.dentalProject'))
                 patient = exocad.parse_dental_project(dental_project_path)
@@ -82,7 +83,7 @@ class TestExocad(unittest.TestCase):
         project_types = filter(lambda x: x.is_dir(), project_types)
         for project_type in project_types:
             for project in project_type.iterdir():
-                if(project.name == 'MissingConstructionInfo'):
+                if project.name == 'MissingConstructionInfo' or project.is_file():
                     continue
                 order = exocad.parse(project)
 
@@ -110,4 +111,14 @@ class TestExocad(unittest.TestCase):
         _, _, _, _, _, order = exocad.parse(project)
         self.logger.info(order.models)
         self.assertGreater(len(order.elements), 0)
-        self.assertGreater(len(order.models), 0)
\ No newline at end of file
+        self.assertGreater(len(order.models), 0)
+
+    def test_abutment_type(self):
+        project = Path('tests/samples/exocad/09_Abutment/154711')
+        _, _, _, _, _, order = exocad.parse(project)
+        self.assertEqual(order.elements[0].teeth[0].implant_system, 'medentika_preface-t_conid : PreFace_T9000-R : T9000-R')
+
+        project = Path('tests/samples/exocad/09_Abutment/156094_krone_inkl_Abutment')
+        _, _, _, _, _, order = exocad.parse(project)
+        self.assertEqual(order.elements[0].teeth[0].implant_system, 'medentika_preface-l_conid : PreFace_L9810-16R-1 : L9810-16R-1')
+        self.assertEqual(order.elements[1].teeth[0].implant_system, None)
